==> jc-1.4.0.tar.gz: soot/relations/JBuddyProfiler__24Info.h <==
// class soot.relations.JBuddyProfiler$Info

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b21a4c19a9803c7f soot_relations_JBuddyProfiler__24Info

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_relations_JBuddyProfiler__24Info_H_
#define _JC_soot_relations_JBuddyProfiler__24Info_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_relations_JBuddyProfiler$object;

// Typedefs
typedef struct _jc_soot_relations_JBuddyProfiler__24Info$sub_refs	_jc_soot_relations_JBuddyProfiler__24Info$sub_refs;
typedef struct _jc_soot_relations_JBuddyProfiler__24Info$sub_nonrefs	_jc_soot_relations_JBuddyProfiler__24Info$sub_nonrefs;
typedef struct _jc_soot_relations_JBuddyProfiler__24Info$refs	_jc_soot_relations_JBuddyProfiler__24Info$refs;
typedef struct _jc_soot_relations_JBuddyProfiler__24Info$nonrefs	_jc_soot_relations_JBuddyProfiler__24Info$nonrefs;
typedef struct _jc_soot_relations_JBuddyProfiler__24Info$object	_jc_soot_relations_JBuddyProfiler__24Info$object;

typedef const struct _jc_soot_relations_JBuddyProfiler__24Info$vmethods	_jc_soot_relations_JBuddyProfiler__24Info$vmethods;
typedef const struct _jc_soot_relations_JBuddyProfiler__24Info$vtable	_jc_soot_relations_JBuddyProfiler__24Info$vtable;
typedef const struct _jc_soot_relations_JBuddyProfiler__24Info$vtype	_jc_soot_relations_JBuddyProfiler__24Info$vtype;

// Constructors
extern void _jc_soot_relations_JBuddyProfiler__24Info$method$_init$86d0fdc62145ba81(_jc_env *, struct _jc_soot_relations_JBuddyProfiler__24Info$object *, struct _jc_soot_relations_JBuddyProfiler$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern jint _jc_soot_relations_JBuddyProfiler__24Info$method$compareTo$84fc6fc4a23c98a3(_jc_env *, struct _jc_soot_relations_JBuddyProfiler__24Info$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_String$object *_jc_soot_relations_JBuddyProfiler__24Info$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_relations_JBuddyProfiler__24Info$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_relations_JBuddyProfiler__24Info$method_info$compareTo$84fc6fc4a23c98a3;
extern _jc_method _jc_soot_relations_JBuddyProfiler__24Info$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_relations_JBuddyProfiler__24Info$vmethods {
	jint	(*compareTo$84fc6fc4a23c98a3)(_jc_env *, struct _jc_soot_relations_JBuddyProfiler__24Info$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_relations_JBuddyProfiler__24Info$object *);
};

// Vtable
struct _jc_soot_relations_JBuddyProfiler__24Info$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_relations_JBuddyProfiler__24Info$vmethods	soot_relations_JBuddyProfiler__24Info;
};

// Vtype
struct _jc_soot_relations_JBuddyProfiler__24Info$vtype {
	_jc_type			type;
	_jc_soot_relations_JBuddyProfiler__24Info$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_relations_JBuddyProfiler__24Info$sub_refs {
	struct _jc_java_lang_String$object	*stackTrace;
	struct _jc_java_lang_String$object	*eventName;
	struct _jc_soot_relations_JBuddyProfiler$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_relations_JBuddyProfiler__24Info$refs {
    _jc_soot_relations_JBuddyProfiler__24Info$sub_refs	soot_relations_JBuddyProfiler__24Info;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_relations_JBuddyProfiler__24Info$sub_nonrefs {
	jlong	time;
};

// Non-reference instance fields (object)
struct _jc_soot_relations_JBuddyProfiler__24Info$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_relations_JBuddyProfiler__24Info$sub_nonrefs	soot_relations_JBuddyProfiler__24Info;
};

// Object instance structure
struct _jc_soot_relations_JBuddyProfiler__24Info$object {
	_jc_soot_relations_JBuddyProfiler__24Info$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_relations_JBuddyProfiler__24Info$vtype	*vtype;
	_jc_soot_relations_JBuddyProfiler__24Info$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_relations_JBuddyProfiler__24Info$vtype _jc_soot_relations_JBuddyProfiler__24Info$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_relations_JBuddyProfiler__24Info, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_relations_JBuddyProfiler__24Info$class_object;

#endif	/* _JC_soot_relations_JBuddyProfiler__24Info_H_ */

==> jc-1.4.6.tar.gz: soot/relations/JBuddyProfiler__24Info.h <==
// class soot.relations.JBuddyProfiler$Info

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b21a4c19a9803c7f soot_relations_JBuddyProfiler__24Info

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_relations_JBuddyProfiler__24Info_H_
#define _JC_soot_relations_JBuddyProfiler__24Info_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_relations_JBuddyProfiler$object;

// Typedefs
typedef struct _jc_soot_relations_JBuddyProfiler__24Info$sub_refs	_jc_soot_relations_JBuddyProfiler__24Info$sub_refs;
typedef struct _jc_soot_relations_JBuddyProfiler__24Info$sub_nonrefs	_jc_soot_relations_JBuddyProfiler__24Info$sub_nonrefs;
typedef struct _jc_soot_relations_JBuddyProfiler__24Info$refs	_jc_soot_relations_JBuddyProfiler__24Info$refs;
typedef struct _jc_soot_relations_JBuddyProfiler__24Info$nonrefs	_jc_soot_relations_JBuddyProfiler__24Info$nonrefs;
typedef struct _jc_soot_relations_JBuddyProfiler__24Info$object	_jc_soot_relations_JBuddyProfiler__24Info$object;

typedef const struct _jc_soot_relations_JBuddyProfiler__24Info$vmethods	_jc_soot_relations_JBuddyProfiler__24Info$vmethods;
typedef const struct _jc_soot_relations_JBuddyProfiler__24Info$vtable	_jc_soot_relations_JBuddyProfiler__24Info$vtable;
typedef const struct _jc_soot_relations_JBuddyProfiler__24Info$vtype	_jc_soot_relations_JBuddyProfiler__24Info$vtype;

// Constructors
extern void _jc_soot_relations_JBuddyProfiler__24Info$method$_init$86d0fdc62145ba81(_jc_env *, struct _jc_soot_relations_JBuddyProfiler__24Info$object *, struct _jc_soot_relations_JBuddyProfiler$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_soot_relations_JBuddyProfiler__24Info$method$compareTo$84fc6fc4a23c98a3(_jc_env *, struct _jc_soot_relations_JBuddyProfiler__24Info$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_relations_JBuddyProfiler__24Info$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_relations_JBuddyProfiler__24Info$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_relations_JBuddyProfiler__24Info$method_info$compareTo$84fc6fc4a23c98a3;
extern _jc_method _jc_soot_relations_JBuddyProfiler__24Info$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_relations_JBuddyProfiler__24Info$vmethods {
	jint	(*compareTo$84fc6fc4a23c98a3)(_jc_env *, struct _jc_soot_relations_JBuddyProfiler__24Info$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_relations_JBuddyProfiler__24Info$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_relations_JBuddyProfiler__24Info$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_relations_JBuddyProfiler__24Info$vmethods	soot_relations_JBuddyProfiler__24Info;
};

// Vtype
struct _jc_soot_relations_JBuddyProfiler__24Info$vtype {
	_jc_type			type;
	_jc_soot_relations_JBuddyProfiler__24Info$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_relations_JBuddyProfiler__24Info$sub_refs {
	struct _jc_java_lang_String$object	*stackTrace;
	struct _jc_java_lang_String$object	*eventName;
	struct _jc_soot_relations_JBuddyProfiler$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_relations_JBuddyProfiler__24Info$refs {
    _jc_soot_relations_JBuddyProfiler__24Info$sub_refs	soot_relations_JBuddyProfiler__24Info;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_relations_JBuddyProfiler__24Info$sub_nonrefs {
	jlong	time;
};

// Non-reference instance fields (object)
struct _jc_soot_relations_JBuddyProfiler__24Info$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_relations_JBuddyProfiler__24Info$sub_nonrefs	soot_relations_JBuddyProfiler__24Info;
};

// Object instance structure
struct _jc_soot_relations_JBuddyProfiler__24Info$object {
	_jc_soot_relations_JBuddyProfiler__24Info$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_relations_JBuddyProfiler__24Info$vtype	*vtype;
	_jc_soot_relations_JBuddyProfiler__24Info$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_relations_JBuddyProfiler__24Info$vtype _jc_soot_relations_JBuddyProfiler__24Info$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_relations_JBuddyProfiler__24Info, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_relations_JBuddyProfiler__24Info$class_object;

#endif	/* _JC_soot_relations_JBuddyProfiler__24Info_H_ */
